cd "C:\Users\Remi\Desktop\Replication Files Jedwab & Vollrath 2018\Figure 1"
set more off

****************
*** FIGURE 1 ***
****************

***************
* INCOME DATA *
***************

*** Income data for the pre-1950 period ***
* The source is Maddison (2008) which was updated by Bolt and van Zanden (2014).
clear
import excel "maddison_new_2010_cleaned_pre_1950.xls", sheet("raw") firstrow clear
drop if country == ""
keep country-y1949
sort country
save maddison_pre_1950, replace

*** Income data for the post-1950 period ***
* The source is Maddison (2008) which was updated by Bolt and van Zanden (2014).
clear
import excel "maddison_new_2010_post_1950.xls", sheet("raw") firstrow clear
drop if country == ""
sort country
merge country using maddison_pre_1950
tab _m
tab country if _m == 1
tab country if _m == 2
drop if _m == 2
* We ignore this observation. 
drop _m
order country continent area y1-y1949 y1950-y2010
* We force the GDP variables to be numeric. 
destring y1-y2010, replace
* If 2010 is missing, we use information from the previous years as long as it is after 2005 (incl.).
replace y2010 = y2009 if y2010 == . 
replace y2010 = y2008 if y2010 == . 
replace y2010 = y2007 if y2010 == . 
replace y2010 = y2006 if y2010 == . 
replace y2010 = y2005 if y2010 == . 
reshape long y, i(country) j(year)
ren y pcgdp
gen lpcgdp = log(pcgdp)
replace country = trim(country)
keep country year lpcgdp
label var country "Country"
label var year "Year"
label var lpcgdp "Log GDP per capita (PPP, constant 1990 dollars)"
sort country year
save maddison_new_2010, replace
count

*********************
* URBANIZATION DATA *
*********************

* We now add the data on urbanization rates (using various sources for that as described in the Web Data Appendix).
clear
import excel "urbanization.xls", sheet("Feuil1")firstrow clear
drop if country == ""
reshape long y, i(country) j(year)
ren y urbrate
sort country year
merge country year using maddison_new_2010
tab _m
drop _m
save data_for_figure1, replace

************
* FIGURE 1 *
************

use data_for_figure1, clear
* We keep the observations for which we have both per capita GDP and urbanization.
keep if urbrate !=. & lpcgdp !=.
* We keep the selected years: 1700, 1913 (which we call "1900"), 1950 and 2010.
keep if 1700 | year == 1913 | year == 1950 | year == 2010
* We obtain the number of available observations for each selected year:
foreach X in 1700 1913 1950  2010 {
count if urbrate != . & lpcgdp != . & year == `X'
}
* 1700 = 18
* 1913 (1900) = 70
* 1950 = 159
* 2010 = 159 

* We first create the figure.
twoway (scatter urbrate lpcgdp if year == 1700, mcolor(gs8) msize(medsmall) msymbol(diamond_hollow))(scatter urbrate lpcgdp if year == 1913, mcolor(gs8) msize(medsmall) msymbol(triangle_hollow))(scatter urbrate lpcgdp if year == 1950, mcolor(gs8) msize(medsmall) msymbol(circle_hollow))(scatter urbrate lpcgdp if year == 2010, mcolor(gs6) msize(medsmall) msymbol(smsquare_hollow))(lfit urbrate lpcgdp if year == 1700)(lfit urbrate lpcgdp if year == 1913, lwidth(thick) lcolor(black) lpattern(solid))(lfit urbrate lpcgdp if year == 1950, lwidth(thick) lcolor(black) lpattern(dash))(lfit urbrate lpcgdp if year == 2010, lwidth(thick) lcolor(black) lpattern(solid)), ytitle(Urbanization Rate (%)) ytitle(, margin(medsmall)) xtitle(Log Per Capita GDP (PPP, Constant 1990$)) xtitle(, margin(small)) legend(order(1 "" 2 "" 3 "" 4 "" 5 "1700" 6 "1900" 7 "1950" 8 "2010") rows(1)) graphregion(margin(vsmall) fcolor(white) lcolor(white) ifcolor(white) ilcolor(white))
* We then manually modify it and save it (figure1.gph) before exporting it. 
graph use "figure1.gph"
graph export figure1.png, replace width(2620) height(1908)


